# Transform statistic

Apply a function to a statistic, and add it as a statistic to the experiment.

First, the module groups the data by the unique values of the variables in By, then applies Function to the statistic in each group.

Note

Statistics are a central part of Cytoflow. More documentation is forthcoming.

Name

  The operation name. Becomes the first part of the new statistic’s name.

Statistic

  The statistic to apply the function to.

Function

  The function to compute on each group.

Subset

  Only apply the function to a subset of the input statistic. Useful if the function is very slow.